/**
 * Copyright (c) 2000-2009, Jasig, Inc.
 * See license distributed with this file and available online at
 * https://www.ja-sig.org/svn/jasig-parent/tags/rel-10/license-header.txt
 */

package org.jasig.web.service;

import java.io.IOException;
import java.util.Map;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestBindingException;

/**
 * @author Eric Dalquist
 * @version $Revision$
 */
public interface AjaxPortletSupport {
    public static final String DEFAULT_AJAX_SERVLET_NAME = "ajaxResponse";
    public static final String DEFAULT_AJAX_HANDLER_ERROR_KEY = "AJAX_HANDLER_ERROR";
    
    /**
     * Generates a new session key and uses that to pass the model to the servlet. The response will be redirected
     * to the ajax handling servlet by this method.
     * 
     * @param ajaxServletName Name of the ajax servlet to redirect to, the full redirect URL is generated by {@link #getAjaxServletUrl(ActionRequest, ActionResponse, String, String)}
     * @param model The data model to pass to the servlet
     */
    public void redirectAjaxResponse(String ajaxServletName, Map<Object, Object> model, ActionRequest request, ActionResponse response) throws IOException;

    /**
     * Calls {@link #redirectAjaxResponse(String, Map, ActionRequest, ActionResponse)} passing {@link #DEFAULT_AJAX_SERVLET_NAME} for the servlet name.
     */
    public void redirectAjaxResponse(Map<Object, Object> model, ActionRequest request, ActionResponse response) throws IOException;
    
    /**
     * Gets the model for the request, if the model is null a 404 is sent to the browser and null is returned. If the
     * model contains the key {@link #DEFAULT_AJAX_HANDLER_ERROR_KEY} a 500 is sent to the browser but the model is still
     * returned for rendering.
     */
    public Map<Object, Object> getAjaxModel(HttpServletRequest request, HttpServletResponse response) throws ServletRequestBindingException, IOException;

}